"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const scripts_1 = __importDefault(require("@digest/scripts"));
const DISABLE_PLUGINS = {
    '@babel/plugin-syntax-dynamic-import': true,
    '@babel/plugin-transform-regenerator': true,
    '@babel/plugin-transform-typescript': true,
    '@dr.pogodin/babel-plugin-react-css-modules': true,
    'babel-plugin-react-remove-properties': true,
    'babel-plugin-transform-inline-environment-variables': true,
    'babel-plugin-transform-node-env-inline': true
};
const DISABLE_PRESETS = {
    'babel-preset-minify': true
};
const babelPrep = function (api) {
    let babelConfig = {};
    if (scripts_1.default.babel) {
        babelConfig = require(scripts_1.default.babel)(api);
    }
    if (babelConfig) {
        const preparedBabelConfig = Object.assign(Object.assign({}, babelConfig), { plugins: babelConfig.plugins ?
                babelConfig.plugins.filter((plugin) => {
                    if (Array.isArray(plugin)) {
                        return !DISABLE_PLUGINS[plugin[0]];
                    }
                    return false;
                }) :
                [], presets: babelConfig.presets ?
                babelConfig.presets.filter((preset) => {
                    if (Array.isArray(preset)) {
                        return !DISABLE_PRESETS[preset[0]];
                    }
                    return false;
                }) :
                [] });
        const presetIndex = preparedBabelConfig.presets.findIndex((preset) => {
            if (Array.isArray(preset)) {
                return preset[0] === '@babel/preset-env';
            }
            return false;
        });
        if (scripts_1.default.cssModules &&
            scripts_1.default.react) {
            preparedBabelConfig.plugins.push([
                '@dr.pogodin/babel-plugin-react-css-modules',
                {
                    context: scripts_1.default.context,
                    generateScopedName: '[local]'
                }
            ]);
        }
        if (scripts_1.default.babelPolyfills &&
            presetIndex > -1) {
            preparedBabelConfig.presets[presetIndex][1].modules = 'commonjs';
            preparedBabelConfig.presets[presetIndex][1].targets = 'node 11';
        }
        else {
            preparedBabelConfig.plugins.unshift([
                '@babel/plugin-transform-modules-commonjs'
            ]);
        }
        return preparedBabelConfig;
    }
    return {};
};
module.exports = babelPrep;
